Tree printing method for list objects. This is an interactive function.
.tree(x, max_levels = 6, ..., verbose = TRUE)The hierarchy as a string, called for side effects
A list
The maximum number of levels to show
Additional arguments:
max_width the number of items horizontally to show before truncating.
max_length the number of items vertically to show before truncating.
others are passed to format(...)
print output to the console (the default)