SurvStat web service relating to a single time period.This function gets a snapshot of disease count or incidence data
from the Robert Koch Institute SurvStat web service, based on either whole
epidemiological season or an individual week within a season. Seasons are
whole years starting either at the beginning of the calendar year, at week 27
or at week 40.
get_snapshot(
disease = NULL,
measure = c("Count", "Incidence"),
...,
season,
season_week = NULL,
season_start = 1,
age_group = NULL,
age_range = c(0, Inf),
disease_subtype = FALSE,
geography = NULL,
.progress = TRUE
)a data frame with at least year (the start of the epidemiological
season) and start_week (the calendar week in which the epidemiological
season starts), and one of count or incidence columns. Most likely it
will also have disease_name and disease_code columns, and some of
age_name, age_code, age_low, age_high, geo_code, geo_name,
disease_subtype_code, disease_subtype_name depending on options.
the disease of interest as a SurvStat key, see
rsurvstat::diseases for a current list of these. This is technically
optional, and if omitted the counts of all diseases will be returned. Keys
are the same as the options in the SurvStat user interface found
here. IfSG
and state variants of diseases are counts that are reported directly to
the Robert Koch Institute or indirectly via state departments.
one of "Count" (default) or "Incidence" per 100,000 per
week or year depending on the context.
not used, must be empty.
the start year of the season in which the snapshot is taken
the start week within the season of the snapshot. If missing then the whole season is used
the week of the calendar year in which the season starts
this can be one of 1, 27 or 40.
(optional) the age group of interest as a SurvStat key,
see rsurvstat::age_groups for a list of valid options.
(optional) a length 2 vector with the minimum and maximum ages to consider
if TRUE the returned count will be broken down by
disease or pathogen subtype (assuming disease was provided).
(optional) a geographical breakdown. This can be given as a
character where it must be one of state, nuts, or county specifying
the 16 region FedStateKey71Map, 38 region NutsKey71Map, or 411 region
CountyKey71Map data respectively. Alternatively it can be given as a
as a sf dataframe, subsetting one of these maps, in which case only that
subset of regions will be returned.
by default a progress bar is shown, which may be important
if many downloads are needed to fulfil the request. It can be disabled
by setting this to FALSE here.
The snapshot can be stratified by any combination of age, geography, disease,
disease subtype. Queries to SurvStat are cached and paged, but obviously
multidimensional extracts have the potential to need a lot of downloading.
# \donttest{
get_snapshot(
diseases$`COVID-19`,
measure = "Count",
season = 2024,
age_group = age_groups$children_coarse
)
get_snapshot(
diseases$`COVID-19`,
measure = "Count",
age_group = age_groups$children_coarse,
season = 2024,
geography = rsurvstat::FedStateKey71Map[1:10,]
)
# }
Run the code above in your browser using DataLab