- disease
the disease of interest as a SurvStat key, see
rsurvstat::diseases for a current list of these. This is technically
optional, and if omitted the counts of all diseases will be returned. Keys
are the same as the options in the SurvStat user interface found
here. IfSG
and state variants of diseases are counts that are reported directly to
the Robert Koch Institute or indirectly via state departments.
- measure
one of "Count" (default) or "Incidence" per 100,000 per
week or year depending on the context.
- ...
not used, must be empty.
- age_group
(optional) the age group of interest as a SurvStat key,
see rsurvstat::age_groups for a list of valid options.
- age_range
(optional) a length 2 vector with the minimum and maximum
ages to consider
- disease_subtype
if TRUE the returned count will be broken down by
disease or pathogen subtype (assuming disease was provided).
- years
(optional) a vector of years to limit the response to. This may
be useful to limit the size of returned pages in the event the SurvStat
service hits a data transfer limit.
- geography
(optional) a geographical breakdown. This can be given as a
character where it must be one of state, nuts, or county specifying
the 16 region FedStateKey71Map, 38 region NutsKey71Map, or 411 region
CountyKey71Map data respectively. Alternatively it can be given as a
as a sf dataframe, subsetting one of these maps, in which case only that
subset of regions will be returned.
- trim_zeros
get rid of zero counts. Either "both" (from start and end),
"leading" (from start only - the default) or "none".
- .progress
by default a progress bar is shown, which may be important
if many downloads are needed to fulfil the request. It can be disabled
by setting this to FALSE here.